==> v1.0.3.tar.gz: nonebot-plugin-marshoai/README_EN.md <==
<!--suppress LongLine -->
<div align="center">
  <a href="https://marsho.liteyuki.icu"><img src="https://marsho.liteyuki.icu/marsho-full.svg" width="800" height="430" alt="MarshoLogo"></a>
  <br>
</div>

<div align="center">

# nonebot-plugin-marshoai

_✨ A chat bot plugin which use OpenAI standard API ✨_

[![NoneBot Registry](https://img.shields.io/endpoint?url=https%3A%2F%2Fnbbdg.lgc2333.top%2Fplugin%2Fnonebot-plugin-marshoai)](https://registry.nonebot.dev/plugin/nonebot-plugin-marshoai:nonebot_plugin_marshoai)
<a href="https://registry.nonebot.dev/plugin/nonebot-plugin-marshoai:nonebot_plugin_marshoai">
  <img src="https://img.shields.io/endpoint?url=https%3A%2F%2Fnbbdg.lgc2333.top%2Fplugin-adapters%2Fnonebot-plugin-marshoai" alt="Supported Adapters">
</a>
<a href="https://pypi.python.org/pypi/nonebot-plugin-marshoai">
    <img src="https://img.shields.io/pypi/v/nonebot-plugin-marshoai.svg" alt="pypi">
</a>
<img src="https://img.shields.io/badge/python-3.10+-blue.svg" alt="python">

</div>

## 📖 Indroduction

A plugin made by call OpenAI standard API(Such as GitHub Models API)

Plugin internally installed the catgirl character of Marsho, is able to have a cute conversation!

*Who don't like a cute catgirl with fast answer speed？*

**Support for adapters other than OneBot and non-Github Models APIs is not fully verified.**

[Melobot implementation](https://github.com/LiteyukiStudio/marshoai-melo)

## 🐱 Character setting

#### Basic information

- Name : Marsho
- Birthday : September 6th

#### Hobbies

- 🌞 Melt in sunshine
- 🤱 Coquetry~ who don't like that~
- 🍫 Eating snacks! Meat is yummy!
- 🐾 Play! I like play with friends!

## 😼 Usage
Please read [Documentation](https://marsho.liteyuki.icu/start/install)

## ❤ Thanks&Copyright
This project uses the following code from other projects:  
- [nonebot-plugin-latex](https://github.com/EillesWan/nonebot-plugin-latex)  

"Marsho" logo contributed by [@Asankilp](https://github.com/Asankilp),licensed under [CC BY-NC-SA 4.0](http://creativecommons.org/licenses/by-nc-sa/4.0/) lisense.  

"nonebot-plugin-marshoai" is licensed under [MIT](./LICENSE-MIT) license.  
Some of the code is licensed under [Mulan PSL v2](./LICENSE-MULAN) license.

<div>
  <a href="https://github.com/LiteyukiStudio/nonebot-plugin-marshoai/graphs/contributors">
    <img src="https://contrib.rocks/image?repo=LiteyukiStudio/nonebot-plugin-marshoai" alt="Contributors">
  </a>
</div>

Thanks to all the contributors!

==> v1.1.4.tar.gz: nonebot-plugin-marshoai/README_EN.md <==
<!--suppress LongLine -->
<div align="center">
  <a href="https://marsho.liteyuki.org"><img src="https://marsho.liteyuki.org/marsho-full.svg" width="800" height="430" alt="MarshoLogo"></a>
  <br>
</div>

<div align="center">

# nonebot-plugin-marshoai

_✨ A chat bot plugin which use OpenAI standard API ✨_

[![NoneBot Registry](https://img.shields.io/endpoint?url=https%3A%2F%2Fnbbdg.lgc2333.top%2Fplugin%2Fnonebot-plugin-marshoai)](https://registry.nonebot.dev/plugin/nonebot-plugin-marshoai:nonebot_plugin_marshoai)
<a href="https://registry.nonebot.dev/plugin/nonebot-plugin-marshoai:nonebot_plugin_marshoai">
  <img src="https://img.shields.io/endpoint?url=https%3A%2F%2Fnbbdg.lgc2333.top%2Fplugin-adapters%2Fnonebot-plugin-marshoai" alt="Supported Adapters">
</a>
<a href="https://pypi.python.org/pypi/nonebot-plugin-marshoai">
    <img src="https://img.shields.io/pypi/v/nonebot-plugin-marshoai.svg" alt="pypi">
</a>
<img src="https://img.shields.io/badge/python-3.10+-blue.svg" alt="python">

</div>

## 📖 Indroduction

A plugin made by call OpenAI standard API(Such as GitHub Models API)

Plugin internally installed the catgirl character of Marsho, is able to have a cute conversation!

*Who don't like a cute catgirl with fast answer speed？*

**Support for adapters other than OneBot and non-Github Models APIs is not fully verified.**

[Melobot implementation](https://github.com/LiteyukiStudio/marshoai-melo)

## 🐱 Character setting

#### Basic information

- Name : Marsho
- Birthday : September 6th

#### Hobbies

- 🌞 Melt in sunshine
- 🤱 Coquetry~ who don't like that~
- 🍫 Eating snacks! Meat is yummy!
- 🐾 Play! I like play with friends!

## 😼 Usage
Please read [Documentation](https://marsho.liteyuki.org/start/use.html)

## ❤ Thanks&Copyright
This project uses the following code from other projects:  
- [nonebot-plugin-latex](https://github.com/EillesWan/nonebot-plugin-latex)  
- [nonebot-plugin-deepseek](https://github.com/KomoriDev/nonebot-plugin-deepseek)

"Marsho" logo contributed by [@Asankilp](https://github.com/Asankilp),licensed under [CC BY-NC-SA 4.0](http://creativecommons.org/licenses/by-nc-sa/4.0/) lisense.  

"nonebot-plugin-marshoai" is licensed under [MIT](./LICENSE-MIT) license.  
Some of the code is licensed under [Mulan PSL v2](./LICENSE-MULAN) license.

<div>
  <a href="https://github.com/LiteyukiStudio/nonebot-plugin-marshoai/graphs/contributors">
    <img src="https://contrib.rocks/image?repo=LiteyukiStudio/nonebot-plugin-marshoai" alt="Contributors">
  </a>
</div>

Thanks to all the contributors!
